@@ -152,7 +152,7 @@ class DatabaseOverviewMetricGroup(MetricGroupDef):
 
         return (select(cols)
                 .select_from(from_clause)
-                .where(c.calls is not None)
+                .where(c.calls != '0')
                 .group_by(c.srvid, c.ts, bs, c.mesure_interval)
                 .order_by(c.ts)
                 .params(samples=100))
@@ -293,6 +293,7 @@ class DatabaseAllRelMetricGroup(MetricGroupDef):
         return (select(cols)
                 .select_from(from_clause)
                 .where(c.datname == bindparam("database"))
+                .where(c.mesure_interval != '0')
                 .group_by(c.srvid, c.ts, c.mesure_interval)
                 .order_by(c.ts)
                 .params(samples=100))
@@ -304,7 +305,7 @@ class ByQueryMetricGroup(MetricGroupDef):
     xaxis = "queryid"
     axis_type = "category"
     data_url = r"/server/(\d+)/metrics/database_all_queries/([^\/]+)/"
-    calls = MetricDef(label="#", type="number")
+    calls = MetricDef(label="#", type="integer")
     runtime = MetricDef(label="Time", type="duration", direction="descending")
     avg_runtime = MetricDef(label="Avg time", type="duration")
     blks_read_time = MetricDef(label="Read", type="duration")
@@ -364,7 +365,7 @@ class ByQueryWaitSamplingMetricGroup(MetricGroupDef):
     xaxis = "query"
     axis_type = "category"
     data_url = r"/server/(\d+)/metrics/database_all_queries_waits/([^\/]+)/"
-    counts = MetricDef(label="# of events", type="number",
+    counts = MetricDef(label="# of events", type="integer",
                        direction="descending")
 
     @property
@@ -467,7 +468,7 @@ class DatabaseOverview(DashboardPage):
             block_graph.color_scheme = ['#cb513a', '#65b9ac', '#73c03a']
 
             sys_graphs = [Graph("System resources (events per sec)",
-                                url="https://powa.readthedocs.io/en/latest/stats_extensions/pg_stat_kcache.html",
+                                url=self.docs_stats_url + "pg_stat_kcache.html",
                                 metrics=[DatabaseOverviewMetricGroup.majflts,
                                          DatabaseOverviewMetricGroup.minflts,
                                          # DatabaseOverviewMetricGroup.nswaps,
@@ -503,7 +504,7 @@ class DatabaseOverview(DashboardPage):
 
             graphs_dash.append(Dashboard("Wait Events",
                 [[Graph("Wait Events (per second)",
-                        url="https://powa.readthedocs.io/en/latest/stats_extensions/pg_wait_sampling.html",
+                        url=self.docs_stats_url + "pg_wait_sampling.html",
                         metrics=metrics)]]))
 
         self._dashboard.widgets.extend(
@@ -540,7 +541,7 @@ class DatabaseOverview(DashboardPage):
         if self.has_extension(self.path_args[0], "pg_wait_sampling"):
             self._dashboard.widgets.extend([[
                 Grid("Wait events for all queries",
-                     url="https://powa.readthedocs.io/en/latest/stats_extensions/pg_wait_sampling.html",
+                     url=self.docs_stats_url + "pg_wait_sampling.html",
                      columns=[{
                        "name": "query",
                        "label": "Query",
