@@ -44,7 +44,7 @@ class ByDatabaseMetricGroup(MetricGroupDef):
     xaxis = "datname"
     data_url = r"/server/(\d+)/metrics/by_databases/"
     axis_type = "category"
-    calls = MetricDef(label="#Calls", type="number", direction="descending")
+    calls = MetricDef(label="#Calls", type="integer", direction="descending")
     runtime = MetricDef(label="Runtime", type="duration")
     avg_runtime = MetricDef(label="Avg runtime", type="duration")
     shared_blks_read = MetricDef(label="Blocks read", type="size")
@@ -101,7 +101,7 @@ class ByDatabaseWaitSamplingMetricGroup(MetricGroupDef):
     data_url = r"/server/(\d+)/metrics/wait_event_by_databases/"
     axis_type = "category"
     counts = MetricDef(label="# of events",
-                       type="number", direction="descending")
+                       type="integer", direction="descending")
 
     @property
     def query(self):
@@ -242,7 +242,7 @@ class GlobalDatabasesMetricGroup(MetricGroupDef):
 
         return (select(cols)
                 .select_from(from_clause)
-                .where(c.calls is not None)
+                .where(c.calls != '0')
                 .group_by(c.srvid, c.ts, bs, c.mesure_interval)
                 .order_by(c.ts)
                 .params(samples=100))
@@ -406,6 +406,7 @@ class GlobalBgwriterMetricGroup(MetricGroupDef):
 
         return (select(cols)
                 .select_from(from_clause)
+                .where(c.mesure_interval != '0')
                 .group_by(c.srvid, c.ts, bs, c.mesure_interval)
                 .order_by(c.ts)
                 .params(samples=100))
@@ -471,6 +472,7 @@ class GlobalAllRelMetricGroup(MetricGroupDef):
 
         return (select(cols)
                 .select_from(from_clause)
+                .where(c.mesure_interval != '0')
                 .group_by(c.srvid, c.ts, c.mesure_interval)
                 .order_by(c.ts)
                 .params(samples=100))
@@ -552,7 +554,7 @@ class ServerOverview(DashboardPage):
             block_graph.color_scheme = ['#cb513a', '#65b9ac', '#73c03a']
 
             sys_graphs = [Graph("System resources (events per sec)",
-                                url="https://powa.readthedocs.io/en/latest/stats_extensions/pg_stat_kcache.html",
+                                url=self.docs_stats_url + "pg_stat_kcache.html",
                                 metrics=[GlobalDatabasesMetricGroup.majflts,
                                          GlobalDatabasesMetricGroup.minflts,
                                          # GlobalDatabasesMetricGroup.nswaps,
@@ -590,7 +592,7 @@ class ServerOverview(DashboardPage):
 
             graphs_dash.append(Dashboard("Wait Events",
                 [[Graph("Wait Events (per second)",
-                        url="https://powa.readthedocs.io/en/latest/stats_extensions/pg_wait_sampling.html",
+                        url=self.docs_stats_url + "pg_wait_sampling.html",
                         metrics=metrics)]]))
 
         dashes = [graphs,
@@ -604,7 +606,7 @@ class ServerOverview(DashboardPage):
 
         if self.has_extension(self.path_args[0], "pg_wait_sampling"):
             dashes.append([Grid("Wait events for all databases",
-                                url="https://powa.readthedocs.io/en/latest/stats_extensions/pg_wait_sampling.html",
+                                url=self.docs_stats_url + "pg_wait_sampling.html",
                                 columns=[{
                                     "name": "datname",
                                     "label": "Database",
